@@ -3,111 +3,201 @@ package JIP::LockFile;
 use 5.006;
 use strict;
 use warnings;
+
 use IO::File;
-use JIP::ClassField 0.05;
 use Carp qw(croak);
 use Fcntl qw(LOCK_EX LOCK_NB);
 use English qw(-no_match_vars);
 
-our $VERSION = '0.051';
+our $VERSION = '0.06';
 
-has [qw(lock_file is_locked)] => (get => q{+}, set => q{-});
+sub is_locked {
+    my ($self) = @ARG;
 
-has fh => (get => q{-}, set => q{-});
+    return $self->{'is_locked'};
+}
+
+sub lock_file {
+    my ($self) = @ARG;
+
+    return $self->{'lock_file'};
+}
 
 sub new {
     my ($class, %param) = @ARG;
 
     # Mandatory options
-    croak q{Mandatory argument "lock_file" is missing}
-        unless exists $param{'lock_file'};
+    if (!exists $param{'lock_file'}) {
+        croak q{Mandatory argument "lock_file" is missing};
+    }
 
     # Check "lock_file"
     my $lock_file = $param{'lock_file'};
-    croak q{Bad argument "lock_file"}
-        unless defined $lock_file and length $lock_file;
+    if (!length $lock_file) {
+        croak q{Bad argument "lock_file"};
+    }
 
     # Class to object
-    return bless({}, $class)
-        ->_set_is_locked(0)
-        ->_set_lock_file($lock_file)
-        ->_set_fh(undef);
+    return bless(
+        {
+            is_locked => 0,
+            lock_file => $lock_file,
+            fh        => undef,
+        },
+        $class,
+    );
 }
 
 # Lock or raise an exception
 sub lock {
-    my $self = shift;
+    my ($self) = @ARG;
 
-    # Re-locking changes nothing
-    return $self if $self->is_locked;
-
-    my $fh = IO::File->new($self->lock_file, O_RDWR|O_CREAT)
-        or croak(sprintf q{Can't open "%s": %s}, $self->lock_file, $OS_ERROR);
-
-    flock $fh, LOCK_EX|LOCK_NB
-        or croak(sprintf q{Can't lock "%s": %s}, $self->lock_file, $OS_ERROR);
-
-    truncate $fh, 0
-        or croak(sprintf q{Can't truncate "%s": %s}, $self->lock_file, $OS_ERROR);
-
-    autoflush $fh 1;
-
-    $fh->print($self->_lock_message())
-        or croak(sprintf q{Can't write message to file: %s}, $OS_ERROR);
-
-    return $self->_set_fh($fh)->_set_is_locked(1);
+    return $self->_lock();
 }
 
 # Or just return undef
 sub try_lock {
-    my $self = shift;
+    my ($self) = @ARG;
 
-    # Re-locking changes nothing
-    return $self if $self->is_locked;
-
-    my $fh = IO::File->new($self->lock_file, O_RDWR|O_CREAT);
-
-    if ($fh and flock $fh, LOCK_EX|LOCK_NB) {
-        truncate $fh, 0
-            or croak(sprintf q{Can't truncate "%s": %s}, $self->lock_file, $OS_ERROR);
-
-        autoflush $fh 1;
-
-        $fh->print($self->_lock_message())
-            or croak(sprintf q{Can't write message to file: %s}, $OS_ERROR);
-
-        return $self->_set_fh($fh)->_set_is_locked(1);
-    }
-    else {
-        return;
-    }
+    return $self->_lock(try => 1);
 }
 
 # You can manually unlock
 sub unlock {
-    my $self = shift;
+    my ($self) = @ARG;
 
     # Re-unlocking changes nothing
-    return $self if not $self->is_locked;
+    return $self if !$self->is_locked;
 
     # Close filehandle before file removing
-    unlink $self->_set_fh(undef)->lock_file
-        or croak(sprintf q{Can't unlink "%s": %s}, $self->lock_file, $OS_ERROR);
+    $self->_set_fh(undef);
+
+    if (!unlink $self->lock_file) {
+        croak sprintf(q{Can't unlink "%s": %s}, $self->lock_file, $OS_ERROR);
+    }
 
     return $self->_set_is_locked(0);
 }
 
+sub get_lock_data {
+    my ($self) = @_;
+
+    my $line;
+    {
+        my $fh
+            = $self->is_locked
+            ? $self->_fh
+            : $self->_init_file_handle;
+
+        return if !$fh;
+
+        $fh->seek(0, 0);
+
+        $line = $fh->getline();
+    }
+
+    return if !$line;
+
+    chomp $line;
+
+    my ($pid, $executable_name) = $line =~ m{
+        ^
+        {
+            "pid":"(\d+)"
+            ,
+            "executable_name":"( [^""]+ )"
+        }
+        $
+    }x;
+
+    return {
+        pid             => $pid,
+        executable_name => $executable_name,
+    };
+}
+
 # unlocking on scope exit
 sub DESTROY {
-    my $self = shift;
+    my ($self) = @ARG;
 
     return $self->unlock;
 }
 
+sub _init_file_handle {
+    my ($self) = @ARG;
+
+    return IO::File->new($self->lock_file, O_RDWR | O_CREAT);
+}
+
+sub _lock {
+    my ($self, %param) = @_;
+
+    # Re-locking changes nothing
+    return $self if $self->is_locked;
+
+    my $fh = $self->_init_file_handle;
+
+    if (!$fh) {
+        return if $param{'try'};
+
+        croak sprintf(q{Can't open "%s": %s}, $self->lock_file, $OS_ERROR);
+    }
+
+    if (!flock $fh, LOCK_EX | LOCK_NB) {
+        return if $param{'try'};
+
+        croak sprintf(q{Can't lock "%s": %s}, $self->lock_file, $OS_ERROR);
+    }
+
+    if (!truncate $fh, 0) {
+        croak sprintf(q{Can't truncate "%s": %s}, $self->lock_file, $OS_ERROR);
+    }
+
+    autoflush $fh 1;
+
+    if (!$fh->print($self->_lock_message)) {
+        croak sprintf(q{Can't write message to file: %s}, $OS_ERROR);
+    }
+
+    return $self->_set_fh($fh)->_set_is_locked(1);
+}
+
 sub _lock_message {
-    return sprintf q[{"pid":"%s","executable_name":"%s"}],
+    return sprintf(
+        q[{"pid":"%s","executable_name":"%s"}],
         $PROCESS_ID,
-        $EXECUTABLE_NAME;
+        $EXECUTABLE_NAME,
+    );
+}
+
+sub _set_is_locked {
+    my ($self, $is_locked) = @ARG;
+
+    $self->{'is_locked'} = $is_locked;
+
+    return $self;
+}
+
+sub _set_lock_file {
+    my ($self, $lock_file) = @ARG;
+
+    $self->{'lock_file'} = $lock_file;
+
+    return $self;
+}
+
+sub _fh {
+    my ($self) = @ARG;
+
+    return $self->{'fh'};
+}
+
+sub _set_fh {
+    my ($self, $fh) = @ARG;
+
+    $self->{'fh'} = $fh;
+
+    return $self;
 }
 
 1;
@@ -120,7 +210,7 @@ JIP::LockFile - application lock/mutex based on files
 
 =head1 VERSION
 
-This document describes C<JIP::LockFile> version C<0.051>.
+This document describes C<JIP::LockFile> version C<0.06>.
 
 =head1 SYNOPSIS
 
@@ -144,6 +234,10 @@ This document describes C<JIP::LockFile> version C<0.051>.
     $wtf->try_lock;  # 0
     $wtf->is_locked; # 0
 
+    # Data from lock-file
+    $foo->get_lock_data->{pid};             # $PROCESS_ID
+    $foo->get_lock_data->{executable_name}; # $EXECUTABLE_NAME
+
     # You can manually unlock
     $foo->unlock;
 
@@ -163,7 +257,7 @@ Vladimir Zhavoronkov, C<< <flyweight at yandex.ru> >>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2015-2018 Vladimir Zhavoronkov.
+Copyright 2015-2020 Vladimir Zhavoronkov.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of the the Artistic License (2.0). You may obtain a
